@@ -290,8 +290,8 @@ function (object,
 
 }
 
-# ------------------------------- PCA objects ----------------------------------------
-plot3dIndiv.pca <-
+# ------------------------------- PCA and SPCA objects ----------------------------------------
+plot3dIndiv.pca <- plot3dIndiv.spca <-
 function (object, 
           comp = 1:3, 
           ind.names = FALSE,
