@@ -32,7 +32,6 @@ function(object, newdata, ...)
     Y = object$Y
     q = ncol(Y)
     p = ncol(X)
-    mode = object$mode
      
     if (length(dim(newdata)) == 2) {
         if (ncol(newdata) != p)
@@ -47,8 +46,6 @@ function(object, newdata, ...)
         dim(newdata) = c(1, p) 
     }
      
-    if (mode == 'canonical') stop("Only 'regression', 'classic' or 'invariant' mode are allowed !")
-     
     #-- initialisation des matrices --#	
     ncomp = object$ncomp
     a = object$loadings$X
@@ -94,7 +91,8 @@ function(object, newdata, ...)
 
 # -------------------------- for plsda and splsda ---------------------------------------
 predict.plsda <- predict.splsda <-
-function(object, newdata, method = c("max.dist", "class.dist", "centroids.dist", "mahalanobis.dist"), ...)  
+function(object, newdata, 
+         method = c("all", "max.dist", "centroids.dist", "mahalanobis.dist"), ...)  
 {
 	#-- validation des arguments --#
     if (missing(newdata))
@@ -102,11 +100,9 @@ function(object, newdata, method = c("max.dist", "class.dist", "centroids.dist",
      
     X = object$X
     Y = object$Y 
-	Yprim = object$ind.mat   
-	q = ncol(Yprim)          
+    Yprim = object$ind.mat   
+    q = ncol(Yprim)          
     p = ncol(X)
-    mode = object$mode
-	method = match.arg(method)
 	
     if (length(dim(newdata)) == 2) {
         if (ncol(newdata) != p)
@@ -121,8 +117,6 @@ function(object, newdata, method = c("max.dist", "class.dist", "centroids.dist",
         dim(newdata) = c(1, p) 
     }
      
-    if (mode == 'canonical') stop("Only 'regression', 'classic' or 'invariant' mode are allowed !")
-     
     #-- initialisation des matrices --#	
     ncomp = object$ncomp
     a = object$loadings$X
@@ -155,113 +149,100 @@ function(object, newdata, method = c("max.dist", "class.dist", "centroids.dist",
 	    t.pred[, h] = scale(newdata, center = means.X, scale = sigma.X) %*% W[, h]
         B.hat[, , h] = B
     }  #end h
-	
-	G = matrix(0, nrow = q, ncol = ncomp)
-	obsLevels = c(1:q)   
-	cl = matrix(nrow = nrow(newdata), ncol = ncomp)
-	
-	for (i in 1:q) {
-		if(ncomp > 1) {
-			G[i, ] = apply(object$variates$X[Yprim[, i] == 1, ], 2, mean)
-		}
-		else {
-			G[i, ] = mean(object$variates$X[Yprim[, i] == 1, ])
-		}
-	}	
-			
+    	
+    G = matrix(0, nrow = q, ncol = ncomp)  
+    cls = list()
+     
+    for (i in 1:q) {
+        if(ncomp > 1) {
+            G[i, ] = apply(object$variates$X[Yprim[, i] == 1, ], 2, mean)
+        }
+        else {
+            G[i, ] = mean(object$variates$X[Yprim[, i] == 1, ])
+        }
+    }	
+		
 	# ----    max distance -----------------
-	if (method == "max.dist") {
-
-	function.pred = function(x){
-		tmp = numeric(nrow(x))
-		for(j in 1:nrow(x)){
-			tmp[j] = (which(x[j,] == max(x[j,]))[1])
-		}
-		return(tmp)
-	}
-	cl = apply(Y.hat, 3, function.pred)
-	} #end method
 	
-	# ----    class distance -----------------
-
-	if (method == "class.dist") {
-	
-		class.fun = function(x, q) {
-			x = matrix(x, q, q, byrow = TRUE)
-			diag(x) = diag(x) - 1
-			d = apply(x^2, 1, sum)
-			cl.id = which.min(d)
-		}
-	
-		for (h in 1:ncomp) {
-			cl.id = apply(Y.hat[, , h], 1, class.fun, q = q)
-			cl[, h]  = as.factor(obsLevels[cl.id])
-		}
-	}	
+    if (any(method == "all") || any(method == "max.dist")) {
+         
+	    function.pred = function(x){
+            nr = nrow(x)
+            tmp = vector("numeric", nr)
+            for(j in 1:nr){
+                tmp[j] = (which(x[j, ] == max(x[j, ]))[1])
+            }
+            return(tmp)
+        }
+        cls$max.dist = matrix(apply(Y.hat, 3, function.pred), ncol = ncomp)
+        colnames(cls$max.dist) = paste(rep("comp", ncomp), 1:ncomp, sep = " ")
+    }
 
 	# ----    centroids distance -----------------
 
-	if (method == "centroids.dist") {
-	
-		centroids.fun = function(x, G, h) {
-			q = nrow(G)
-			x = matrix(x, nrow = q, ncol = h, byrow = TRUE)
-			if (h > 1) {
-				d = apply((x - G[, 1:h])^2, 1, sum)
-			}
-			else {
-				d = (x - G[, 1])^2
-			}
-			cl.id = which.min(d)
-		}
-		
-		for (h in 1:ncomp) {
-			cl.id = apply(as.matrix(t.pred[, 1:h]), 1, centroids.fun, G = G, h = h)
-			cl[, h]  = as.factor(obsLevels[cl.id])		
-		}
-	}	
+	if (any(method == "all") || any(method == "centroids.dist")) {
+     
+        cl = matrix(nrow = nrow(newdata), ncol = ncomp)
+         
+        centroids.fun = function(x, G, h) {
+            q = nrow(G)
+            x = matrix(x, nrow = q, ncol = h, byrow = TRUE)
+            if (h > 1) {
+                d = apply((x - G[, 1:h])^2, 1, sum)
+            }
+            else {
+                d = (x - G[, 1])^2
+            }
+            cl.id = which.min(d)
+        }
+	    	
+        for (h in 1:ncomp) {
+            cl.id = apply(matrix(t.pred[, 1:h], ncol = h), 1, centroids.fun, G = G, h = h)
+            cl[, h] = cl.id		
+        }
+        colnames(cl) = paste(rep("comp", ncomp), 1:ncomp, sep = " ")
+        cls$centroids.dist = cl
+    }	
 
 	# ----    mahalanobis distance -----------------
 	
-	if (method == "mahalanobis.dist") {
-	
-		Sr.fun = function(x, G, Yprim, h) {
-			q = nrow(G)
-			Xe = Yprim %*% G[, 1:h]
-			Xr = object$variates$X[, 1:h] - Xe
-			Sr = t(Xr) %*% Xr / nrow(Y)
-			Sr.inv = solve(Sr)
-			x = matrix(x, nrow = q, ncol = h, byrow = TRUE)
-			if (h > 1) {
-				mat = (x - G[, 1:h]) %*% Sr.inv %*% t(x - G[, 1:h])
-				d = apply(mat^2, 1, sum)
-			}
-			else {
-				d = drop(Sr.inv) * (x - G[, 1])^2
-			}
-			cl.id = which.min(d)
-		}
-		
-		for (h in 1:ncomp) {
-			cl.id = apply(as.matrix(t.pred[, 1:h]), 1, Sr.fun, G = G, Yprim = Yprim, h = h)
-			cl[, h]  = as.factor(obsLevels[cl.id])		
-		}
-	}
+    if (any(method == "all") || any(method == "mahalanobis.dist")) {
+     
+        cl = matrix(nrow = nrow(newdata), ncol = ncomp)
+         
+        Sr.fun = function(x, G, Yprim, h) {
+            q = nrow(G)
+            Xe = Yprim %*% G[, 1:h]
+            Xr = object$variates$X[, 1:h] - Xe
+            Sr = t(Xr) %*% Xr / nrow(Y)
+            Sr.inv = solve(Sr)
+            x = matrix(x, nrow = q, ncol = h, byrow = TRUE)
+            if (h > 1) {
+                mat = (x - G[, 1:h]) %*% Sr.inv %*% t(x - G[, 1:h])
+                d = apply(mat^2, 1, sum)
+            }
+            else {
+                d = drop(Sr.inv) * (x - G[, 1])^2
+            }
+            cl.id = which.min(d)
+        }
+	     	
+        for (h in 1:ncomp) {
+            cl.id = apply(matrix(t.pred[, 1:h], ncol = h), 1, Sr.fun, G = G, Yprim = Yprim, h = h)
+            cl[, h] = cl.id		
+        }
+        colnames(cl) = paste(rep("comp", ncomp), 1:ncomp, sep = " ")
+        cls$mahalanobis.dist = cl
+    }
 	
     #-- valeurs sortantes --#
+    if (any(method == "all")) method = "all"
     rownames(t.pred) = rownames(newdata)
     colnames(t.pred) = paste("dim", c(1:ncomp), sep = " ")
     rownames(Y.hat) = rownames(newdata)
     colnames(Y.hat) = colnames(Y)
     colnames(G) = paste("dim", c(1:ncomp), sep = " ")
-    # KA: added a !is.null(dim(cl) for loocv
-    if(!is.null(dim(cl))) {
-	colnames(cl) = paste(rep("comp", ncomp), 1:ncomp, sep = " ")
-	}
-	else {
-		names(cl) = paste(rep("comp", ncomp), 1:ncomp, sep = " ")
-	}
      
     return(invisible(list(predict = Y.hat, variates = t.pred, B.hat = B.hat, 
-		                  centroids = G, method = method, class = cl)))
+		                  centroids = G, method = method, class = cls)))
 }
